@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,7 +32,7 @@ public:
 
     void createIfMissing();
 
-    static QString akonadiNotesInstanceName();
+    static Q_REQUIRED_RESULT QString akonadiNotesInstanceName();
 
 protected:
     virtual void finishCreateResource();
